==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WeightedCloseIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ItemwiseStrategyBasedIndicatorDescriptionMetadata } from "./ItemwiseStrategyBasedIndicatorDescriptionMetadata";
import { WeightedCloseIndicatorDescription } from "./WeightedCloseIndicatorDescription";
/**
 * @hidden
 */
var WeightedCloseIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WeightedCloseIndicatorDescriptionMetadata, _super);
    function WeightedCloseIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WeightedCloseIndicatorDescriptionMetadata.b = function (a) {
        if (WeightedCloseIndicatorDescriptionMetadata.a == null) {
            WeightedCloseIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WeightedCloseIndicatorDescriptionMetadata.c(WeightedCloseIndicatorDescriptionMetadata.a);
        }
        if (a.k(WeightedCloseIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.aa(WeightedCloseIndicatorDescriptionMetadata.a);
    };
    WeightedCloseIndicatorDescriptionMetadata.c = function (a) {
        ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    WeightedCloseIndicatorDescriptionMetadata.d = function (a) {
        WeightedCloseIndicatorDescriptionMetadata.b(a);
        a.ac("WeightedCloseIndicator", function () { return new WeightedCloseIndicatorDescription(); });
        a.ab("WeightedCloseIndicator", WeightedCloseIndicatorDescriptionMetadata.a);
    };
    WeightedCloseIndicatorDescriptionMetadata.$t = markType(WeightedCloseIndicatorDescriptionMetadata, 'WeightedCloseIndicatorDescriptionMetadata');
    WeightedCloseIndicatorDescriptionMetadata.a = null;
    return WeightedCloseIndicatorDescriptionMetadata;
}(Base));
export { WeightedCloseIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WeightedCloseIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ItemwiseStrategyBasedIndicatorDescriptionMetadata } from "./ItemwiseStrategyBasedIndicatorDescriptionMetadata";
import { WeightedCloseIndicatorDescription } from "./WeightedCloseIndicatorDescription";
/**
 * @hidden
 */
var WeightedCloseIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WeightedCloseIndicatorDescriptionMetadata, _super);
    function WeightedCloseIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WeightedCloseIndicatorDescriptionMetadata.b = function (a) {
        if (WeightedCloseIndicatorDescriptionMetadata.a == null) {
            WeightedCloseIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WeightedCloseIndicatorDescriptionMetadata.c(WeightedCloseIndicatorDescriptionMetadata.a);
        }
        if (a.k(WeightedCloseIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.ac(WeightedCloseIndicatorDescriptionMetadata.a);
    };
    WeightedCloseIndicatorDescriptionMetadata.c = function (a) {
        ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    WeightedCloseIndicatorDescriptionMetadata.d = function (a) {
        WeightedCloseIndicatorDescriptionMetadata.b(a);
        a.ae("WeightedCloseIndicator", function () { return new WeightedCloseIndicatorDescription(); });
        a.ad("WeightedCloseIndicator", WeightedCloseIndicatorDescriptionMetadata.a);
    };
    WeightedCloseIndicatorDescriptionMetadata.$t = markType(WeightedCloseIndicatorDescriptionMetadata, 'WeightedCloseIndicatorDescriptionMetadata');
    WeightedCloseIndicatorDescriptionMetadata.a = null;
    return WeightedCloseIndicatorDescriptionMetadata;
}(Base));
export { WeightedCloseIndicatorDescriptionMetadata };
